import {
  select,
  scaleOrdinal,
  schemeSpectral
} from 'd3';
import { getData } from './data';
import { colorLegend } from './legend';
import { earthMap } from '/map';

// Get the SVG from the DOM
const svg = select('svg');

// Add a Group for the earth
const earthGroup = svg.append('g');
// Add a Group for the Legend
const legendGroup = svg.append('g')
	.attr('transform',`translate(18,300)`);

// Init the ColorScale
const colorScale = scaleOrdinal();
const colorValue = d => d.properties.economy;

let countryData;
let selectedValue;

// On Click event of the Legend
const onLegendClick = d => {
  selectedValue = d===selectedValue ? null : d
  render();
};

// Render Function
const render = () => {
  // Determine the ColorScale
  colorScale
    .domain(countryData.map(colorValue))
  	.domain(colorScale.domain().sort().reverse())
  	.range(schemeSpectral[colorScale.domain().length]);
  
  // Add the Legend
  legendGroup
    .call(colorLegend, {
      colorScale,
    	legendWidth: 240,
      itemRadius: 8,
      itemSpacing: 20,
      itemTextPos: 12,
    	onClick: onLegendClick,
    	selectedValue: selectedValue
  });

  // Add the Earth
	earthGroup
  	.call( earthMap, {
    	countryData,
    	colorScale,
    	colorValue,
    	selectedValue
  });
};

getData()
  .then(data => {
  	// Render when the data is loaded
  	countryData = data;
   	render();
});