// Render the Color Legend
export const colorLegend = (selection, props) => {
  // Deconstruct the props argument
  const {
    colorScale,
    legendWidth,
    itemRadius,
    itemSpacing,
    itemTextPos,
    onClick,
    selectedValue
  } = props;

  // Add a Background
  const backgroundRect = selection.selectAll('rect')
  	.data([null]);
  backgroundRect.enter().append('rect')
  	.merge(backgroundRect)
  		.attr('x',-itemRadius*2)
  		.attr('y',-itemRadius*2)
  		.attr('rx',itemRadius)
  		.attr('width', legendWidth)
  		.attr('height',( colorScale.domain().length * itemSpacing ) + itemRadius)
  		.attr('fill','white')
  		.attr('opacity',0.8);

  // Create a Group Element
  const groups = selection.selectAll('g')
  	.data(colorScale.domain().reverse());
  const groupsEnter = groups
  	.enter().append('g')
  		.attr('class','tick');
  groupsEnter
    .merge(groups)
  		.attr('transform', (d, i) =>
      	`translate(0,${i * itemSpacing})`
      )
  		.attr('opacity', d =>	(!selectedValue || d===selectedValue)? 1 : 0.2)
  		.on('click', onClick)
  	;
  groups.exit().remove();
  
  // Append Child Elements to the Group
  groupsEnter.append('circle')
  	// Use merge to Update Existing DOM Elements
  	.merge(groups.select('circle'))
  		.attr('r', itemRadius)
      .attr('fill', colorScale);

  // Append Child Elements to the Group
  groupsEnter.append('text')
  		.attr('x',itemTextPos)
  		.attr('dy', 0.32 +'em')
   	// Use merge to Update Existing DOM Elements
  	.merge(groups.select('text'))
  		.text(d => d);
 
}