import {
  geoPath,
  geoNaturalEarth1,
  zoom,
  event
} from 'd3';

// Init Topographic Projection
const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

// Render the Color Legend
export const earthMap = (selection, props) => {
  // Deconstruct the props argument
  const {
    countryData,
    colorScale,
    colorValue,
    selectedValue
  } = props;
  
  const gUpdate = selection.selectAll('g').data([null]);
  const gEnter = gUpdate.enter().append('g');
  const g = gUpdate.merge(gEnter);
  
  // Add the Sphere / Ocean
  gEnter
    .append('path')
    	.attr('d', pathGenerator({type: 'Sphere'}))
    	.attr('class', 'ocean')
  	.merge(gUpdate.select('.ocean'))
  		.attr('opacity', d=> selectedValue ? 0.4 : 1);

  // Add zoom to the SVG
  selection.call(zoom().on('zoom', () => {
    g.attr('transform', event.transform);
  }));

  // Add the Countries
  const countryPaths = g.selectAll('.land')
    .data(countryData);
  const countryPathsEnter = countryPaths
    .enter().append('path')
    	.attr('class', 'land')
      .attr('d', pathGenerator)
  		.attr('fill', d => colorScale(colorValue(d)));
  countryPaths
  	.merge(countryPathsEnter)
  		.attr('opacity', d=> (!selectedValue || selectedValue===colorValue(d)) ? 1 : 0.4)
  		.classed('highlighted', d=> selectedValue && selectedValue===colorValue(d));
  countryPathsEnter
     .append('title')
       .text(d => d.properties.name + ': ' + colorValue(d));
  
}